pygeodesy.geodesici.Intersectool5Tuple

Package pygeodesy :: Module geodesici :: Class Intersectool5Tuple |
[frames] | no frames]

# Class Intersectool5Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       Intersectool5Tuple

Known Subclasses:
  - Intersector5Tuple
  - , Middle5Tuple

5-Tuple `(A, B, sAB, aAB, c)` with `A` and `B` the `Position` of the intersection on each geodesic line, the distance `sAB` between `A` and `B` in `meter`, the angular distance `aAB` in `degrees` and coincidence indicator `c` (`int`), see XDict.

Note: `A` and `B` are each a `GDict` with `lat1`, `lon1` and `azi1` or `lat2`, `lon2` from the geodesic line `glA` respectively `glB` and the intersection location in `latX`, `lonX`, distance `s1X` in `meter` and angular distance `a1X` in `degrees` and the segment indicator `kX`. See XDict for more details.

Instance Methods
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`